@@ -4,7 +4,6 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-
 #ifndef GDRIVEUDSENTRY_H
 #define GDRIVEUDSENTRY_H
 
@@ -18,7 +17,7 @@ enum GDriveUDSEntryExtras {
     Version,
     LastModifyingUser,
     Description,
-    SharedWithMeDate
+    SharedWithMeDate,
 };
 
 #endif // GDRIVEUDSENTRY_H
